@@ -15,9 +15,19 @@ class Test_parse_settings(unittest.TestCase):
                     'debugtoolbar.intercept_exc':'false',
                     'debugtoolbar.intercept_redirects': 'false',
                     'debugtoolbar.panels': panels,
+                    'debugtoolbar.extra_panels': (
+                        'pyramid_debugtoolbar.tests.test_init.DummyCustomPanel'),
                     'debugtoolbar.global_panels': global_panels,
+                    'debugtoolbar.extra_global_panels': (
+                        'pyramid_debugtoolbar.tests.test_init.DummyGlobalPanel'),
                     'debugtoolbar.hosts': '127.0.0.1',
                     'debugtoolbar.exclude_prefixes': '/excluded\n/e2',
+                    'debugtoolbar.debug_notfound': 'false',
+                    'debugtoolbar.debug_routematch': 'false',
+                    'debugtoolbar.reload_templates': 'false',
+                    'debugtoolbar.reload_resources': 'false',
+                    'debugtoolbar.reload_assets': 'false',
+                    'debugtoolbar.prevent_http_cache': 'false',
                     }
         result = self._callFUT(settings)
         self.assertEqual(result,
@@ -25,16 +35,24 @@ class Test_parse_settings(unittest.TestCase):
                           'debugtoolbar.intercept_exc': False,
                           'debugtoolbar.intercept_redirects': False,
                           'debugtoolbar.panels': [DummyPanel, DummyPanel],
+                          'debugtoolbar.extra_panels': [DummyCustomPanel],
                           'debugtoolbar.global_panels': [DummyPanel, DummyPanel],
+                          'debugtoolbar.extra_global_panels': [DummyGlobalPanel],
                           'debugtoolbar.exclude_prefixes': ['/excluded', '/e2'],
                           'debugtoolbar.hosts': ['127.0.0.1'],
+                          'debugtoolbar.debug_notfound': False,
+                          'debugtoolbar.debug_routematch': False,
+                          'debugtoolbar.reload_templates': False,
+                          'debugtoolbar.reload_resources': False,
+                          'debugtoolbar.reload_assets': False,
+                          'debugtoolbar.prevent_http_cache': False,
                           }
                          )
 
 class Test_includeme(unittest.TestCase):
     def setUp(self):
         self.config = testing.setUp()
-        
+
     def _callFUT(self, config):
         from pyramid_debugtoolbar import includeme
         return includeme(config)
@@ -53,3 +71,9 @@ class Test_includeme(unittest.TestCase):
 
 class DummyPanel(object):
     pass
+
+class DummyCustomPanel(object):
+    pass
+
+class DummyGlobalPanel(object):
+    pass
