@@ -47,12 +47,12 @@ class DebugToolbar(object):
         # XXX
         for panel_class in panel_classes:
             panel_inst = panel_class(request)
-            if panel_inst.dom_id() in activated and panel_inst.has_content:
+            if panel_inst.dom_id in activated and panel_inst.has_content:
                 panel_inst.is_active = True
             self.panels.append(panel_inst)
         for panel_class in global_panel_classes:
             panel_inst = panel_class(request)
-            if panel_inst.dom_id() in activated and panel_inst.has_content:
+            if panel_inst.dom_id in activated and panel_inst.has_content:
                 panel_inst.is_active = True
             self.global_panels.append(panel_inst)
 
@@ -115,21 +115,26 @@ def toolbar_tween_factory(handler, registry, _logger=None):
         _logger = logger
     settings = registry.settings
 
-    if not get_setting(settings, 'enabled'):
+    def sget(opt, default=None):
+        return get_setting(settings, opt, default)
+
+    if not sget('enabled'):
         return handler
 
     request_history = ToolbarStorage(100)
     registry.request_history = request_history
 
     redirect_codes = (301, 302, 303, 304)
-    panel_classes = get_setting(settings, 'panels', [])
-    global_panel_classes = get_setting(settings, 'global_panels', [])
-    intercept_exc = get_setting(settings, 'intercept_exc')
-    intercept_redirects = get_setting(settings, 'intercept_redirects')
-    show_on_exc_only = get_setting(settings, 'show_on_exc_only')
-    hosts = get_setting(settings, 'hosts')
+    panel_classes = sget('panels', [])
+    panel_classes.extend(sget('extra_panels', []))
+    global_panel_classes = sget('global_panels', [])
+    global_panel_classes.extend(sget('extra_global_panels', []))
+    intercept_exc = sget('intercept_exc')
+    intercept_redirects = sget('intercept_redirects')
+    show_on_exc_only = sget('show_on_exc_only')
+    hosts = sget('hosts')
     auth_check = registry.queryUtility(IRequestAuthorization)
-    exclude_prefixes = get_setting(settings, 'exclude_prefixes', [])
+    exclude_prefixes = sget('exclude_prefixes', [])
     registry.exc_history = exc_history = None
     registry.pdtb_token = hexlify(os.urandom(10))
 
